==> qtjambi-qt3drender-6.4.1-sources.jar: io/qt/qt3d/render/QTexture1D.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a Target1D target format</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qtexture1d.html">Qt3DRender::QTexture1D</a></p>
 */
public class QTexture1D extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture1D.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture1D(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture1D() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexture1d.html#QTexture1D">Qt3DRender::QTexture1D::QTexture1D(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture1D(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture1D instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTexture1D(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTexture1D(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTexture1D instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.1-sources.jar: io/qt/qt3d/render/QTexture1D.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>A QAbstractTexture with a Target1D target format</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qtexture1d.html">Qt3DRender::QTexture1D</a></p>
 */
public class QTexture1D extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture1D.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture1D(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture1D() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexture1d.html#QTexture1D">Qt3DRender::QTexture1D::QTexture1D(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture1D(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture1D instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QTexture1D(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QTexture1D(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTexture1D instance, QDeclarativeConstructor constructor);
    
}
